
$ontext
This code replicates the world food prices under the REG model.
The values of all parameters are deterministic.
Under the REG model, the US Renewable Fuel Standard (RFS) is implemented.
The model is calibrated for the base year 2012.

$offtext


********************************************************************************************************
****Section 1: PARAMETERS USED IN THE MODEL
********************************************************************************************************


SETS
   t       time period     /1*15/
   region  three geographical regions: the United States india  the Rest of the World  /usa,row, india/
   k       six food commodities / rice,wheat,sugar,corn,other_food,meat-dairy/
   ct      land of quality n: three land classes are defined /I,II,III/
   i       resources used to produce transport fuel: oil first-generation biofuel second-generation biofuel /oil,firstbiofuel,secondbiofuel/
   alias(t,tt);

SCALARS
   ir  annual interest rate /0.02/



****PART 1: DEMAND FOR FOOD AND TRANSPORT ENERGY


*******GDP per capita and population

PARAMETERS
gdpini(region) GDP per capita in 2012 PPP (2005 US dollars)___data are from EIA (2015)
                           / usa     43210
                             india    3295
                             row     10714 /


TABLE
g(region,t)   GDP per capita annual growth rate___data are from EIA (2015): we adopt their intermediate oil price projections
              1       2       3       4        5        6        7         8        9         10       11       12        13       14       15
    usa       0.0148  0.0106  0.0150  0.0160   0.0160   0.0160   0.0177    0.0166   0.0152    0.0138   0.0143   0.0153    0.0167   0.0174   0.0175
    india     0.0370  0.0279  0.0278  0.0428   0.0415   0.0420   0.0450    0.0475   0.0476    0.0482   0.0462   0.0495    0.0484   0.0342   0.0353
    row       0.0181  0.0169  0.0245  0.0306   0.0328   0.0320   0.0308    0.030    0.0289    0.0288   0.0287   0.030     0.0303   0.0291   0.0287    ;



PARAMETERS
Pop0(region)  Population in 2012 (billion people)__Data are from UNDP 2010
                        / usa     0.310
                         india    1.224
                          row     5.360/;

TABLE
gp(t,region)  Population annual growth rate__Data are from UNDP 2010: we adopt their medium range fertility projections
                  usa     india    row
           1      0.0085  0.0132   0.0106
           2      0.0085  0.0132   0.0106
           3      0.0085  0.0132   0.0106
           4      0.0085  0.0132   0.0106
           5      0.0085  0.0132   0.0106
           6*10   0.0080  0.0117   0.0097
           11*15  0.0074  0.0102   0.0087
           ;

PARAMETERS
income(region,t) regional GDP per capita at time t (PPP 2005 US dollars)
Pop(region,t)    regional population at time t (billion people);

income(region,"1")= GDPini(region);
Loop(t,  income(region,t+1) = (income(region,t)* ((1+g(region,t))) ) );

Pop(region,"1")= Pop0(region);
Loop( t, Pop(region,t+1) =( Pop(region,t)*((1+gp(t,region)))) );





*******Demand for food commodities

PARAMETERS
p_ini(k) Food prices in 2012 (US dollars per ton)__Data are from World Bank: Commodity Markets Outlook (2015)

              /rice   550
             wheat    250
            sugar     500
             corn     286
        other_food    280
        meat-dairy    1960/



TABLE
dem_ini(k,region)  Demand for food in 2012 (in tons per capita per year)__Data from FAOSTAT: food balance sheet (2016)
                           usa         india   row
                   rice    0.00747    0.0703   0.05306
                  wheat    0.07952    0.05708  0.06632
                  sugar    0.06065    0.02323  0.02214
                   corn    0.01245    0.00627  0.02054
            other_food     0.119      0.080    0.116
          meat-dairy       0.375      0.075    0.070;




TABLE
alphaini(k,region) Own-price elasticities__Data sources are detailed
*1) in footnote 26 of the main paper
*2) under table A6 of the web appendix
                          usa    india    row
                rice    -0.15   -0.35    -0.20
              wheat     -0.15   -0.35    -0.20
              sugar     -0.23   -0.57    -0.25
              corn      -0.15   -0.35    -0.20
         other_food     -0.23   -0.53    -0.30
         meat-dairy     -0.28   -0.371   -0.30;


TABLE
betaini(k,region)  Income elasticities__Data are detailed
*1) in footnote 26 of the main paper
*2) under table A6 of the web appendix
                         usa     india    row
                  rice   0.14    0.57     0.65
                 wheat   0.14    0.57     0.65
               sugar     0.41    0.71     0.71
                 corn    0.14    0.57     0.65
            other_food   0.41    0.71     0.71
           meat-dairy    0.43    0.97     0.77   ;

TABLE
Plim (k,region) Reservation price for food commodities (dollars per ton)
                    usa     india   row
              rice  10000    10000  10000
             wheat  10000    10000  10000
           sugar    10000    10000  10000
             corn   10000    10000  10000
       other_food   10000    10000  10000
       meat-dairy   50000    50000  50000;
*we introduce a limit price for food commodities. Thus, the consumer surplus has an upper value.
*Since we fix a very high reservation price, the results are not sensitive to this value.


PARAMETERS
  alpha(k,region)    Own-price elasticity at time t
  beta(k,region,t)   Income elasticity at time t
  b(k,region)        Constant demand parameter calibrated to reproduce demand for food commodities over the base year (see equation 14)
  gamma(k,region,t)  Term involved in the periodical adjustment of final demand
  dplim (k,region,t) Per capita demand for food commodities at the reservation price (Plim) at time t
;





alpha(k,region) = alphaini(k,region);
beta(k,region,t) = betaini(k,region);

b(k,region)=  dem_ini(k,region)*[p_ini(k)**(-alpha(k,region))]*[GDPini(region)**(-betaini(k,region))];
Loop(k, gamma(k,region,t)= b(k,region)*income(region,t)**beta(k,region,t));

dplim (k,region,t)  = ( 1/(Plim(k,region)**(-alpha(k,region))) )*gamma(k,region,t);





*******Demand for transport fuel

PARAMETERS
dem_ener_ini(region) Per capita demand for transport fuel in 2012 (MegaJoules per capita)__Data sources are from EIA (2014)
              /usa     54400
               india     573
               row      4320/


PARAMETER
p_ener_ini(region) Price of blended fuel in 2012 (US dollars per MegaJoules)__Data sources are detailed
*1) in footnote 26 of the main paper
*2) under table A6 of the web appendix
              /usa    0.023
               india  0.027
               row    0.025   /

alphaener(region) Own-price elasticity for transport fuel__Data sources are detailed
*1) in footnote 26 of the main paper
*2) under table A6 of the web appendix
               /    usa   -0.50
                 india    -0.21
                    row   -0.78/

betaener(region)  Income elasticity for transport fuel__Data sources are detailed
*1) in footnote 26 of the main paper
*2) under table A6 of the web appendix
                 /    usa  0.94
                   india   1.30
                      row  1.20/

Plimener (region) Reservation price for transport fuel (dollars per ton)
                   /   usa   10000
                     india   10000
                       row   10000/ ;

PARAMETERS
Dct(region)          Constant demand parameter calibrated to reproduce demand for transport fuel in the base year (see equation 14)
Gammaener(region,t)  Term involved in the periodical adjustment of demand for transport fuel
dPlimener (region,t) Per capita demand for transport at the reservation price (Plim) at time t;


Dct(region)=  dem_ener_ini(region)*[p_ener_ini(region)**(-alphaener(region))]*[GDPini(region)**(-betaener(region))];
gammaener(region,t) = Dct(region)*(income(region,t))**betaener(region);
Dplimener (region,t)  = { 1/[Plimener(region)**(-alphaener(region))] }*gammaener(region,t);



****PART 2: SUPPLY FOR FOOD AND ENERGY

*********Land availability, land quality and crop yields

TABLE
La(ct, region) Land currently under crop cultivation by land quality and region (billion hectares)__Data are from FAO-IIASA (2002) and FAO (2016)

                                  usa      india  row
                             I    0.06     0.07   0.2
                            II    0.07     0.06   0.4
                            III   0.02     0.01   0.5;


TABLE
  yieldcini(k,region,ct) Crop yield by land quality and region in 2012 (tons per hectare)__Data are from FAO-IIASA (2002) and FAO (2016)


                                         I        II       III
                     rice.usa            7.1      5.1      3.5
                     rice.india          3.2      2.8      1.8
                     rice.row            5        3        2
                     wheat.usa           6.9      5        2.9
                     wheat.india         4.1      1.8      1.5
                     wheat.row           2.9      1.8      0.8
                     sugar.usa           86       62       55
                     sugar.india         79       60       52
                     sugar.row           70       60       55
                     corn.usa            9.37     7.06     4.68
                     corn.india          3.97     3.35     1.88
                     corn.row            4.68     4.31     2.65
                     other_food.usa      4.5      3.5      2.5
                     other_food.india    3        2.5      1.5
                     other_food.row      3.2      2.8      1.5
                     meat-dairy.usa      4.25     3.5      1.5
                     meat-dairy.india    3.5      1.75     1
                     meat-dairy.row      3.5      1.7      1;



TABLE
inigy(k,region,ct)   Initial annual crop yield growth rate by land quality and region__Data are calculated from historical data: FAO (2016)

                                     I      II        III
                  rice.usa          0.0119 0.0119    0.0119
                  rice.india        0.0118 0.0118    0.0188
                  rice.row          0.0120 0.0120    0.0120
                  wheat.usa         0.0150 0.0150    0.0150
                  wheat.india       0.0135 0.0135    0.0135
                  wheat.row         0.0120 0.0120    0.0120
                  sugar.usa         0.0019 0.0019    0.0019
                  sugar.india       0.0019 0.0019    0.0019
                  sugar.row         0.0019 0.0019    0.0019
                  corn.usa          0.0150 0.0150    0.0150
                  corn.india        0.0135 0.0135    0.0135
                  corn.row          0.0120 0.0120    0.0120
                  other_food.usa    0.0150 0.0150    0.015
                  other_food.india  0.0119 0.0119    0.0119
                  other_food.row    0.0120 0.0120    0.0120
                  meat-dairy.usa    0.0120 0.0120    0.0120
                  meat-dairy.india  0.0118 0.0118    0.0118
                  meat-dairy.row    0.0120 0.0120    0.012



TABLE
 decgy(k,region,ct) Rate of decrease of crop yield growth rate by land quality and region__Data are calculated from historical data: FAO (2016)
                                        I       II        III
                  rice.usa             0.01    0.01      0.01
                  rice.india           0.01    0.01      0.01
                  rice.row             0.01    0.01      0.01
                  wheat.usa            0.01    0.01      0.01
                  wheat.india          0.01    0.01      0.01
                  wheat.row            0.01    0.01      0.01
                 sugar.usa             0.01    0.01      0.01
                 sugar.india           0.01    0.01      0.01
                 sugar.row             0.01    0.01      0.01
                  corn.usa             0.01    0.01      0.01
                  corn.india           0.01    0.01      0.01
                  corn.row             0.01    0.01      0.01
                  other_food.usa       0.01    0.01      0.01
                  other_food.india     0.01    0.01      0.01
                  other_food.row       0.01    0.01      0.01
                  meat-dairy.usa       0.01    0.01      0.01
                  meat-dairy.india     0.01    0.01      0.01
                  meat-dairy.row       0.01    0.01      0.01                  ;




PARAMETERS
Yield(k,region,ct,t)  Crop yield by land quality and region at time t
gy(k,region,ct,t)     Growth Rate of the agricultural yield by land quality and region at time t;

gy(k,region,ct,"1")=inigy (k,region,ct);
yield(k,region,ct,"1")= Yieldcini(k,region,ct);
Loop( t, gy(k,region,ct,t+1)= gy(k,region,ct,t)*(1-decgy(k,region,ct)));
Loop (ct, Loop( t, yield(k,region,ct,t+1)=(yield(k,region,ct,t)*(1+gy(k,region,ct,t)) )  ));



***Idle lands
TABLE
forest(ct,region) Idle lands available for food or biofuel (billion hectares)__Data are from FAO-IIASA (2002) and FAO (2016)
**the area available for cultivation is supposed to be nil in india
**the area available for cultivation in the row mainly comes from Latin America and Africa

                                  usa     india   row
                             I     0       0       0
                            II    0.01     0       0.25
                            III   0.01     0       0.25;


**Parameters for unit cost of conversion of land into farming for each land quality (see equation 11)
*Data are from Sohngen and Mendelsohn (2003)
PARAMETERS

alpha_cost(region)
           /usa        430
            row         56
            india      200  /

beta_cost(region)
           /usa        431
            row        106
            india      200/

gamma_cost(region)
           /usa         197
            row        1417
            india       65 /



**Transformation of crops into six final food commodities
TABLE
coefconvini (k,region) Coefficient of conversion of crops into final food commodities__date sources are detailed in the main paper see the end of the paragraph supply of food and biofuels
*-footnote 21 of the main paper
                                    usa    india  row
                       rice         0.95   0.95   0.95
                       wheat        0.95   0.95   0.95
                       sugar        0.95   0.95   0.95
                       corn         0.95   0.95   0.95
                       other_food   0.95   0.95   0.95
                       meat-dairy   0.4    0.25   0.25;

TABLE
costconvini(k,region)  Cost of conversion of crops into one ton of final product($ per ton)

                                    usa    india  row
                            rice    400    340    350
                            wheat   120    190    190
                            sugar   520    450    450
                            Corn    120    190    190
                      other_food    220    220    200
                      meat-dairy   1200   1200   1500;


PARAMETERS
coefconv(k,region,t)        Coefficient of conversion of crops into final products at time t
costconv(k,region,t)        Cost of conversion of crops into final products at time t
yieldfinal(k,region,ct,t)   Number of food commodities obtained per unit of land per land quality and region (tons per hectare);

coefconv(k,region,t) = coefconvini(k,region);
costconv(k,region,t)=costconvini(k,region);
yieldfinal(k,region,ct,t) = yield(k,region,ct,t)*coefconv(k,region,t);


*****Parameters: unit cost of oil (see equation 13)

SCALAR
Ini_cost_ress Unit extraction cost over the base year (in gallons)
      /2.50/


SCALAR
Final_cost_ress Unit extraction cost of the last unit of oil (i.e if the stock is completely exhausted)
        /7.76/

SCALAR
Slope_ress Slope of the marginal extraction cost
      /15/

SCALAR
Reserves Reserves in 2012 (billion gallons)__Data are from British Petroleum (2013) and IEA (2014)
       /35427/

PARAMETERS

Oil_tax(region) Unit tax on gasoline

        /usa    0.38
         india  0
         row    0    /


TABLE
Gal_MJ(i,region) coefficient of conversion of gallon into megajoule
                           usa       india     row
              oil          120       120       120
              firstbiofuel  80        80        80  ;

**conversion of resource (oil or crop) into final energy (gasoline or biofuels)
TABLE
v(i,region) coefficient of conversion resource (oil or crop) into final energy (gasoline or biofuels)__Data sources are detailed in the web appendix in Table A3.
               usa   india    row
 oil           0.48   0.48    0.24
 firstbiofuel  205    16      22
 secondbiofuel 1800   0       0 ;
*Please note that in our model second-generation are assumed to be produced only in the USA, so, we do not need to specify v("secondbiofuel",region).

TABLE
zini(i,region) conversion cost of resource (oil or crop) into final energy (gasoline or biofuels)__Data sources are detailed in the web appendix in Table A3.

                  usa       india    row
  oil            0.4599    0.5599   0.5599
  firstbiofuel   0.73      1.06     0.63
  secondbiofuel  1.10      2.00     2.00   ;

PARAMETERS
energy_cos_dec(i) rate of decrease of conversion cost
               /oil            0.01
                firstbiofuel   0.015
                secondbiofuel  0.015/;

PARAMETERS
z(i,region,t)          Unit cost of conversion of primary ressource (oil or crop) into final energy (gasoline or biofuels) at time t
bio_cost(region,t)     Unit production production of biofuels (net of the cost of land which is endogenous in the model) at time t
bio_yield(region,ct,t) Biofuel yield: product of primary crop yield times the coefficient of conversion of crop into biofuels (gallons per hectare) at time t
second_cost(region,t)  Cost of second generation biofuels in US dollars per gallon at time t ;


z(i,region,"1")=zini(i,region);
Loop(t, z(i,region,t+1) = z(i,region,t)*(1-energy_cos_dec(i))$(Ord(t)<12 )+ z(i,region,t)$(Ord(t)>=12));
bio_cost(region,t)      = z("firstbiofuel",region,t) ;
bio_yield("usa",ct,t)   = yieldfinal("other_food","usa",ct,"1")*v("firstbiofuel","usa");
bio_yield("India",ct,t) = yieldfinal("sugar","India",ct,"1")*v("firstbiofuel","India");
bio_yield("row",ct,t)   = yieldfinal("sugar","row",ct,"1")*v("firstbiofuel","row");
second_cost(region,t)   = z("secondbiofuel",region,t) ;

*bio_yield are reported in Table 3



****Parameters used to calibrate the constant of the supply function (see equation 12)

TABLE
x(i,region) Demand for each ressource in 2012 (Megajoules)__Data sources are EIA (2014)
                           usa      india    row
            oil            15000     540    22000
            firstbiofuel     790      40     1040;


PARAMETERS
sigma(region) Elasticity of substitution__Data source are from Hertel (2010)
                 /usa     2
                india     2
                   row    2/

y(region) Transport fuel supply in 2012 (MegaJoules)__Data sources are EIA (2014)
            /  usa   16400
             india     688
                row  23155 /


TABLE
Theta(i,region) Share of each ressource__They are calculated from observed values in 2012
                     usa    india  row
              oil    0.93   0.95   0.90
      firstbiofuel   0.07   0.05   0.10;

PARAMETERS
lambda(region)         Constant demand parameter calibrated to transport fuel supply over the base year (see equation 12 and footnote 23 of the main paper)
;

lambda(region)    = y(region)/[theta("oil",region)*x("oil",region)**[(sigma(region)-1)/sigma(region)]+ theta("firstbiofuel",region)*x("firstbiofuel",region)**[(sigma(region)-1)/sigma(region)]]**(sigma(region)/[sigma(region)-1]) ;


****PART 3: THE RENEWABLE FUEL STANDARD (RFS)


PARAMETERS
first_targets_usa(t)  Minimum of first-genration biofuels (see figure 1 in the main paper)
 /1   12
  2   12.6
  3   13.2
  4   13.8
  5   14.4
  6   15
7*15  15/

second_targets_usa(t) Minimum use of advanced biofuels (see figure 1 in the main paper)
 /1   0.95
  2   1.35
  3   2.00
  4   2.75
  5   3.75
  6   5.5
  7   7.25
  8   11.0
  9   13.0
  10  15.0
  11  21.0
  12  21.0
13*15 21.0       /
*We implicitly assume that the target on advanced biofuels is only met by second-generation biofuel.



********************************************************************************************************
****Section 2: VARIABLES AND EQUATIONS OF THE MODEL
********************************************************************************************************



VARIABLES

dk(k,region,t)                Per capita demand for food commodity k at time t
Lu(ct,region,t)               Area under crop cultivation for each land quality and each region at time t
primaire(ct,k,region,t)       Crop production used to produced final food commodity k for each land quality and each region at time t
trade_agri(k,region,t)        Excess demand for crop k in each region at time t t
forest_conv(ct,region,t)      Idle lands for each land quality and each region at time t
d(region,t)                   Per capita demand for transport fuel at time t
qe(i,region,t)                Domestic production of resource i
dem_input(i,region,t)         Domestic demand for resource i
prim_ener(ct,i,region,t)      Crop production used to produce first-generation biofuel for each land quality and each region at time t
supply_oil(t)                 Oil extracted at time t
trade_bio_usa(t)              net imports of biofuels in the USA at time t
land_second(ct,t)             Area allocated to second-generation biofuels in the USA at time t
second_usa(t)                 Production of second-generation of biofuels in the USA at time t
*Please note that in our model second-generation are assumed to be produced only in the USA

***Objective function
Netbenland   Net surplus  from food
NetBenener   Net surplus from energy
Netben       Sum of net surplus derived from food and net surplus derived from energy;


POSITIVE VARIABLES
 Lu,primaire,d,dk,qe,dem_input,prim_ener,supply_oil,Forest_conv, land_second,second_usa;



****Upper and Lower Bounds: General conditions imposed for stability
d.l(region,t) = dem_ener_ini(region);
d.up(region,t) = 190000;
d.lo(region,t) = 0.1;
dk.lo(k,region,t)= 0.0001;
dk.up(k,region,t)= 250;
dk.l(k,region,t) = dem_ini(k,region);
*primaire.lo(u,ct,k,region,t)=0.00001;
primaire.up(ct,k,region,t)=10000;
*prim_ener.lo(u,ct,i,region,t)=0.00001;
prim_ener.up(ct,i,region,t)=10000;
dem_input.lo(i,region,t) = 0.001;
dem_input.up(i,region,t) = 10000;
qe.lo(i,region,t) = 0.001;
qe.up(i,region,t) = 10000;
dem_input.l(i,region,t)=x(i,region);
trade_bio_usa.l(t)=3;
trade_bio_usa.lo(t)=0.001;




EQUATIONS
  primaireeq(ct,region,t)
  biofueleq(i,region,t)           domestic production of first-generation biofuels at time t
  landeq(ct,region,t)             equation stated that area allocated to food and first-and-second generation biofuels production should be lower or equal to total area cultivated
  forest_eq(ct,region,t)          equation stated that area of idle lands converted into cultivation should be lower or equal to initial idle lands
  trade_agrieq(k,region,t)        trade equation: net imports food commodities
  trade_agri_equi(k,t)            equation stated that world food production is equal to world food demand (the shadow price of this equation is interpreted as the world food price)

  supply_dem_oil(t)               equation stated that world oil production is equal to world oil demand
  second_usa_eq(t)                domestic production of second-generation biofuels__USA
  enereq_usa(region,t)            CES production function for transport fuel__USA
  enereq_indiarow(region,t)       CES production function for transport fuel__India and ROW
  trade_ener_usa(t)               trade equation: net exports of first generation biofuels in the usa
  trade_ener_india(t)             trade equation: net exports of first generation biofuels in India
  trade_ener_eq(t)                trade equation: sum of net exports from ROW and net exports from USA is equal to 0
****RFS
  mandate_USA(t)                  RFS (first generation biofuels)
  mandate_usa_second(t)           RFS (second geneartion biofuels)
****
  contposar(k,region,t)           positive control constraint_food commodities
  contpos(region,t)               positive control constraint_transport fuel
  contposinput(i,region,t)        positive control constraint_resource

  Netbenlandeq        net suplus derived from food
  NetBenenereq        net suplus derived from energy
  Netbeneq            sum of net surplus derived from food and net surplus derived from energy;


  contposar (k,region,t) ..   dk(k,region,t) =g= 0.001 ;

  primaireeq(ct,region,t) ..  sum(k, primaire(ct,k,region,t)/[Yieldfinal(k,region,ct,t)]) + {prim_ener(ct,"firstbiofuel",region,t)/bio_yield(region,ct,t)} =l= Lu(ct,region,t);


  Landeq(ct,region,t).. Lu(ct,region,t)+ land_second(ct,t)$(ord(region) le 1)=l= La(ct,region)+ sum(tt $(ord(tt) le ord(t)), forest_conv(ct,region,tt)) ;


  forest_eq(ct,region,t) .. forest(ct,region) =g=  sum(tt $(ord(tt) le ord(t)), forest_conv(ct,region,tt));

   biofueleq(i,region,t)$(ord(i) eq 2).. qe("firstbiofuel",region,t) =l= sum(ct, prim_ener(ct,"firstbiofuel",region,t));

   second_usa_eq(t) .. second_usa(t) =e= sum(ct, land_second(ct,t))*v("secondbiofuel","usa");

trade_agrieq(k,region,t) .. trade_agri(k,region,t) =e= dk(k,region,t)*pop(region,t) - sum(ct,primaire(ct,k,region,t));

trade_agri_equi(k,t)..  sum(region, trade_agri(k,region,t))=e= 0;


 Netbenlandeq .. NetBenland =e= ( sum (t,
     (sum(region,
     (Pop(region,t)*
     sum( k,(
    ( gamma(k,region,t)**((-1)/alpha(k,region)) ) *
    (alpha(k,region)/(1+alpha(k,region)))*
    ( (1/(dk(k,region,t)**(-((1/alpha(k,region))+1))))- (1/(dPlim(k,region,t)**(-((1/alpha(k,region))+1
      ))) ))
  + DPlim(k,region,t)*Plim(k,region)
    )
 )
 )

- sum(k,costconv(k,region,t)*sum(ct,primaire(ct,k,region,t)))
  )  )
- sum(region $(ord(region) le 2), sum(ct $(ord(ct) ge 2),
- (alpha_cost(region)*[(-1)*(log10[{forest(ct,region)- sum(tt $(ord(tt) le ord(t)), forest_conv(ct,region,tt))+0.00001}/forest(ct,region)])] + beta_cost(region)+gamma_cost(region)*{(forest_conv(ct,region,t+1)-forest_conv(ct,region,t)) /(forest_conv(ct,region,t)+0.1)})*(forest_conv(ct,region,t))

)

)
  *(1+ir)**((1-ord(t)))
      ) );


****Energy sector
 contpos(region,t).. d(region,t)=g= 0.1;

 contposinput(i,region,t)$(ord(i) le 3).. dem_input(i,region,t)=g= 0.01;


 supply_dem_oil(t) .. supply_oil(t) =e= sum(region, dem_input("oil", region,t));

 mandate_USA(t) .. [dem_input("firstbiofuel","usa",t)] =g= first_targets_USA(t);

 mandate_usa_second(t) .. second_usa(t) =e= second_targets_usa(t);

 enereq_usa(region,t)$(ord(region) eq 1) .. d(region,t)*pop(region,t) =e=
  {lambda(region)*[
 [Theta("oil",region)*[dem_input("oil",region,t)*Gal_MJ("oil",region)]**[(sigma(region)-1)/sigma(region)]]
+[Theta("firstbiofuel",region)*
 {  [(dem_input("firstbiofuel",region,t)+second_targets_usa(t))*Gal_MJ("firstbiofuel",region)]
 }
 **[(sigma(region)-1)/sigma(region)]]
 ]**(1/[(sigma(region)-1)/sigma(Region)]) };

 enereq_indiarow(region,t)$(ord(region) ge 2) .. d(region,t)*pop(region,t) =e=
  {lambda(region)*[
 [Theta("oil",region)*[dem_input("oil",region,t)*Gal_MJ("oil",region)]**[(sigma(region)-1)/sigma(region)]]
+[Theta("firstbiofuel",region)*
 {  [(dem_input("firstbiofuel",region,t))*Gal_MJ("firstbiofuel",region)]
 }
 **[(sigma(region)-1)/sigma(region)]]
 ]**(1/[(sigma(region)-1)/sigma(Region)]) };





trade_ener_eq(t) ..  qe("firstbiofuel","row",t) - dem_input("firstbiofuel","ROW",t) =e= trade_bio_usa(t);;

trade_ener_india(t) ..  dem_input("firstbiofuel","india",t) =e= qe("firstbiofuel","india",t);

trade_ener_usa(t) .. trade_bio_usa(t) =e= - dem_input("firstbiofuel","usa",t)+ qe("firstbiofuel","usa",t);





 NetBenenereq.. NetBenener=E=

  Sum(t,
  [ sum(region, (
   pop(region,t)*(
  ( gammaener(region,t)**(-1/alphaener(region)) )*( alphaener(region)/(1+alphaener(region)) )*
  ( d(region,t)**(1/alphaener(region)+1)-plimener(region)**(1/alphaener(region)+1) )
  $(abs(alphaener(region))>1) +
  ( gammaener(region,t)**(-1/alphaener(region)) )*( alphaener(region)/(1+alphaener(region)) ) *
  ( (1/d(region,t))**(-(1/alphaener(region)+1)) -1/plimener(region)**(-(1/alphaener(region)+1)) )$(abs(alphaener(region))<1)

  + DPlimener(region,t)*Plimener(region)
 )

 ))

 - second_cost("usa",t)*second_usa(t)
 - sum(region, [z("oil",region,t)+ Oil_Tax(region)]*dem_input("oil",region,t))
 -   [Ini_cost_ress + Final_cost_ress*(sum(tt $ (ord(tt) le ord(t)), supply_oil(tt))/reserves)**Slope_ress]*supply_oil(T)
 - sum(region, bio_cost(region,t)*qe("firstbiofuel",region,t) )


 ]*(1+ir)**((1-Ord(t)))

  );

***Objective function
  Netbeneq .. NetBen =e= Netbenener + Netbenland;

***Solver used
 option nlp=minos;

***Option for GAMS output report
 option decimals=4;
 option reslim = 1500;
 option limrow = 0;
 option limcol = 0;
 option solprint = on;
 option iterlim = 900000;

***Model statement
 Model agrifordyn /all/;
 agrifordyn.workspace = 150;

***Scale
 file fopt/minos.opt/;
 put fopt;
 put "scale all variables"/;
 putclose;
 agrifordyn.optfile = 1;

***Solve statement
Solve agrifordyn using nlp maximising Netben ;


********************************************************************************************************
****Section 3: Export GAMS OUTPUT
********************************************************************************************************
*Food prices for the six food commodities in 2022
PARAMETERS
price_food(k,t) world prices for each food commodity;

price_food(k,"11") = ( trade_agri_equi.m(k,"11"));

*GAMS output
display price_food;




********************************************************************************************************
****Section 4: SENSITIVITY ANALYSIS
********************************************************************************************************
*To run the sensitivity analysis, we shock each parameter once at a time by applying the shock reported
*in Table A10 of the web appendix.





