
*** This code replicates the results for distributional effects through expenditure and overall welfare effects *** 
*** Figures 3,5,6,7,8 and Tables 5,10,11,12 based on Schedules 1 and 10 of NSS 66 data ***
***--------------------------------------------------------------------------------------------****

use hh66.dta, clear

** Consumption survey

	* Expenditure shares

gen sh_1 =(vl30rice)/hhexp
gen sh_2 =(vl30wheat)/hhexp
gen sh_3 =(vl30sugar)/hhexp
gen sh_4 =(vl30meat)/hhexp
gen sh_5 =(vl30other)/hhexp
gen sh_6=(vl30corn)/hhexp

		*Table 5:

	save hh66.dta, replace
    keep if sector==1
		
		xtile q=lmpce, nq(10)
		mean sh_*[fw = hhwt], over(q) 

	save hh66_rural.dta, replace
	
	use hh66.dta, clear
    keep if sector==2
	
		xtile q=lmpce, nq(10)
		mean sh_*[fw = hhwt], over(q) 
	
	save hh66_urban.dta, replace
		
*RURAL:
		
use hh66_rural.dta, clear

	gen poor=0 if pce!=.
	replace poor=1*hhsize if pce<pline

	gen poorhh=0 if pce!=.
	replace poorhh=1 if pce<pline

mean pce [fw=hhwt] 

	gen mpoor=0 if pce!=.
	replace mpoor=1 if pce>=(pline*0.95) & pce<=(pline*1.05)

merge 1:1 _n using MCResults.dta, nogen

  forv i=1/6 {
	sum sh_`i' if mpoor==1
		scalar mp_`i'=r(mean)
		 }

* perfect pass-through - rural
****************************

gen k=0
gen cmean=0
gen csum=0
gen cse=0
gen csqdev=0
gen wmean=0
gen wsum=0
gen wse=0
gen wsqdev=0
gen pmean=0
gen psum=0
gen pse=0
gen psqdev=0
gen zsum=0
gen zmean=0
gen welfare=0

qui forv k=1/500{

gen r = uniform() if price1!=.
sort r
    gen select =_n==1
	scalar P1=price1
    scalar P2=price2 
    scalar P3=price3 
    scalar P4=price4 
    scalar P5=price5
	scalar P6=price6
drop r select
	
	gen concost_`k'=-(P1*sh_1+P2*sh_2+P3*sh_3+P4*sh_4+P5*sh_5+P6*sh_6)
	gen dz`k'=(P1*mp_1+P2*mp_2+P3*mp_3+P4*mp_4+P5*mp_5+P6*mp_6)
	
replace k=`k'
replace csum=csum+concost_`k'
replace cmean=csum/`k'

replace csqdev=csqdev+((cmean-concost_`k')^2)
replace cse=sqrt(csqdev/(`k'*(`k'-1)))

replace wsum=wsum+concost_`k'
replace wmean=wageeff_perfect+csum/`k'

replace wsqdev=wsqdev+((cmean-concost_`k')^2) 
replace wse=sqrt(wsqdev/(`k'*(`k'-1)))

			replace zsum=zsum+dz`k'
			replace zmean=zsum/`k'
					sum zmean if mpoor==1 
					scalar line=pline*(1+r(mean))
		
			gen newpoor`k'=0
			replace newpoor`k'=1 if new_pce<=line
			gen pinc`k'=newpoor`k'-poorhh
			
			sum pinc`k' [fw=hhwt]
				gen np`k'=r(mean)
			replace psum=psum+np`k'
			replace pmean=psum/`k'

			replace psqdev=psqdev+((pmean-np`k')^2)
			replace pse=sqrt(psqdev/(`k'*(`k'-1)))
		
drop concost_`k' dz`k' pinc`k' newpoor`k' np`k' 
}

drop k csum csqdev wsum wsqdev psum psqdev zsum zmean

	gen cmean100=cmean*100
	gen wmean100=wmean*100
    gen wageeff100=wageeff_perfect*100  if wmean!=.
	gen cse100=cse*100
	gen ese100=ese*100
	gen wse100=wse*100
			
	save hh66_rural_perfect.dta,replace

			log on

			*Rural perfect (Table 10)  
			mean *100 [fw = hhwt], over(q)
			*Rural perfect (Table 11) 
			mean pmean pse [fw = hhwt]
	
			log off
			

**Lpoly Graphs Data (Figures 5, 6 and 7):

lpoly cmean100 lmpce, bwidth(1) degree(1) noscatter generate(grid cons_rp) nograph se(secons)
lpoly wageeff100 lmpce, bwidth(1) degree(1) noscatter generate(grid2 wage_rp) nograph se(sewage)
lpoly wmean100 lmpce, bwidth(1) degree(1) noscatter generate(grid3 welf_rp) nograph se(sewelf)

		gen l_ci1_rp=cons_rp-1.96*secons
		gen u_ci1_rp=cons_rp+1.96*secons
		gen l_ci2_rp=wage_rp-1.96*sewage
		gen u_ci2_rp=wage_rp+1.96*sewage
		gen l_ci3_rp=welf_rp-1.96*sewelf
		gen u_ci3_rp=welf_rp+1.96*sewelf


save hh66_rural_perfect,replace
		rename grid gridr
		drop if gridr==.	
		keep cons wage_rp gridr welf_rp l_ci* u_ci*
save lpolyresults.dta, replace


  * Rural Imperfect
	use hh66_rural.dta, replace
	merge 1:1 _n using MCResults.dta, nogen
	
gen k=0
gen cmean=0
gen csum=0
gen cse=0
gen csqdev=0
gen wmean=0
gen wsum=0
gen wse=0
gen wsqdev=0
gen pmean=0
gen psum=0
gen pse=0
gen psqdev=0
gen zsum=0
gen zmean=0
gen psum2=0
gen pmean2=0
gen pse2=0
gen psqdev2=0
gen welfare=0

qui forv k=1/500{

gen r = uniform() if price1!=.
sort r
    gen select =_n==1
	merge m:1 product using pe.dta, nogen  	
drop r select
	
	gen concost_`k'=-(P1*sh_1+P2*sh_2+P3*sh_3+P4*sh_4+P5*sh_5+P6*sh_6)
	gen dz`k'=(P1*mp_1+P2*mp_2+P3*mp_3+P4*mp_4+P5*mp_5+P6*mp_6)
	
replace k=`k'
replace csum=csum+concost_`k'
replace cmean=csum/`k'

replace csqdev=csqdev+((cmean-concost_`k')^2)
replace cse=sqrt(csqdev/(`k'*(`k'-1)))

replace wsum=wsum+concost_`k'
replace wmean=wageeff_imperfect+csum/`k'

replace wsqdev=wsqdev+((cmean-concost_`k')^2) 
replace wse=sqrt(wsqdev/(`k'*(`k'-1)))


	replace zsum=zsum+dz`k'
	replace zmean=zsum/`k'
			sum zmean if mpoor==1 
			scalar line=pline*(1+r(mean))
	
		gen newpoor`k'=0
        replace newpoor`k'=1 if new_pce2<=line
	    gen pinc`k'=newpoor`k'-poorhh
		
		sum pinc`k' [fw=hhwt]
			gen np`k'=r(mean)
	    replace psum=psum+np`k'
        replace pmean=psum/`k'

		replace psqdev=psqdev+((pmean-np`k')^2)
        replace pse=sqrt(psqdev/(`k'*(`k'-1)))
		
drop concost_`k' dz`k' pinc`k' newpoor`k' np`k' 
}

	
	gen cmean100i=cmean*100
	gen wmean100i=wmean*100
    gen wageeff100i=wageeff_imperfect*100 if wmean!=.
	gen cse100i=cse*100
	gen ese100i=ese2*100
	gen wse100i=wse*100
	

save hh66_rural_imperfect.dta,replace
	
		log on

		*Rural Imperfect (Table 10)
		mean *100i [fw = hhwt], over(q)
		*Rural Imperfect (Table 11)
		mean pmean pse [fw = hhwt]
	
		log off

		
		merge 1:1 id using hh66_rural_perfect.dta, keepusing(cmean100 cse100 wageeff100 ese100 wmean100 wse100)

		
**Lpoly Graphs Data Figures 5, 6 and 7):

		
lpoly cmean100i lmpce, bwidth(1) degree(1) noscatter generate(grid cons_ri) nograph se(secons)
lpoly wageeff100i lmpce, bwidth(1) degree(1) noscatter generate(grid2 wage_ri) nograph se(sewage)
lpoly wmean100i lmpce, bwidth(1) degree(1) noscatter generate(grid3 welf_ri) nograph se(sewelf)

			gen l_ci1_ri=cons_ri-1.96*secons
			gen u_ci1_ri=cons_ri+1.96*secons
			gen l_ci2_ri=wage_ri-1.96*sewage
			gen u_ci2_ri=wage_ri+1.96*sewage
			gen l_ci3_ri=welf_ri-1.96*sewelf
			gen u_ci3_ri=welf_ri+1.96*sewelf


save hh66_rural_imperfect.dta,replace

			keep cons wage_ri gridr welf_ri l_ci* u_ci*	
			merge 1:1 gridr using lpolyresults.dta, nogen

save lpolyresults.dta, replace


*URBAN

use hh66_urban.dta, clear

	gen poor=0 if pce!=.
	replace poor=1*hhsize if pce<pline

	gen poorhh=0 if pce!=.
	replace poorhh=1 if pce<pline

mean pce [fw=hhwt] /*Pre-policy average consumption: */

gen mpoor=0 if pce!=.
replace mpoor=1 if pce>=(pline*0.95) & pce<=(pline*1.05) 


merge 1:1 _n using MCResults.dta, nogen

  forv i=1/6 {
	sum sh_`i' if mpoor==1
		scalar mp_`i'=r(mean)
		 }
	

* Perfect Pass-through  - Urban

gen k=0
gen cmean=0
gen csum=0
gen cse=0
gen csqdev=0
gen wmean=0
gen wsum=0
gen wse=0
gen wsqdev=0
gen pmean=0
gen psum=0
gen pse=0
gen psqdev=0
gen zsum=0
gen zmean=0
gen welfare=0

qui forv k=1/500{

gen r = uniform() if price1!=.
sort r
    gen select =_n==1
	scalar P1=price1
    scalar P2=price2 
    scalar P3=price3 
    scalar P4=price4 
    scalar P5=price5 
drop r select
	
	gen concost_`k'=-(P1*sh_1+P2*sh_2+P3*sh_3+P4*sh_4+P5*sh_5+P6*sh_6)
	gen dz`k'=(P1*mp_1+P2*mp_2+P3*mp_3+P4*mp_4+P5*mp_5+P6*mp_6)
	
replace k=`k'
replace csum=csum+concost_`k'
replace cmean=csum/`k'

replace csqdev=csqdev+((cmean-concost_`k')^2)
replace cse=sqrt(csqdev/(`k'*(`k'-1)))

replace wsum=wsum+concost_`k'
replace wmean=wageeff_perfect+csum/`k'

replace wsqdev=wsqdev+((cmean-concost_`k')^2) 
replace wse=sqrt(wsqdev/(`k'*(`k'-1)))

replace zsum=zsum+dz`k'
replace zmean=zsum/`k'
		sum zmean if mpoor==1 
		scalar line=pline*(1+r(mean))
		

		gen newpoor`k'=0
        replace newpoor`k'=1 if new_pce<=line
	    gen pinc`k'=newpoor`k'-poorhh
		
		sum pinc`k' [fw=hhwt]
			gen np`k'=r(mean)
	    replace psum=psum+np`k'
        replace pmean=psum/`k'

		replace psqdev=psqdev+((pmean-np`k')^2)
        replace pse=sqrt(psqdev/(`k'*(`k'-1)))
		
drop concost_`k' dz`k' pinc`k' newpoor`k' np`k' 
}
	
	gen cmean100=cmean*100
	gen wmean100=wmean*100
    gen wageeff100=wageeff_perfect*100 if wmean!=.
	gen cse100=cse*100
	gen ese100=ese*100
	gen wse100=wse*100
	

	save hh66_urban_perfect.dta,replace

		log on

		*Urban Perfect (Table 10)
		mean *100 [fw = hhwt], over(q)	
		*Urban Perfect (Table 11)
		mean pmean pse [fw = hhwt]
	
		log off

	**Lpoly Graphs Data (Figures 5, 6 and 7):
	
lpoly cmean100 lmpce, bwidth(1) degree(1) noscatter generate(grid cons_up) nograph se(secons)
lpoly wageeff100 lmpce, bwidth(1) degree(1) noscatter generate(grid2 wage_up) nograph se(sewage)
lpoly wmean100 lmpce, bwidth(1) degree(1) noscatter generate(grid3 welf_up) nograph se(sewelf)

gen l_ci1_up=cons_up-1.96*secons
gen u_ci1_up=cons_up+1.96*secons
gen l_ci2_up=wage_up-1.96*sewage
gen u_ci2_up=wage_up+1.96*sewage
gen l_ci3_up=welf_up-1.96*sewelf
gen u_ci3_up=welf_up+1.96*sewelf


save hh66_urban_perfect.dta,replace

	keep cons wage_up gridu welf_up l_ci* u_ci*
	append using lpolyresults.dta
	save lpolyresults.dta, replace	


*****************
	
   * Urban Imperfect
	use hh66_urban.dta, replace
	
	merge 1:1 _n using MCResults.dta, nogen
	
gen k=0
gen cmean=0
gen csum=0
gen cse=0
gen csqdev=0
gen wmean=0
gen wsum=0
gen wse=0
gen wsqdev=0
gen pmean=0
gen psum=0
gen pse=0
gen psqdev=0
gen zsum=0
gen zmean=0
gen psum2=0
gen pmean2=0
gen pse2=0
gen psqdev2=0
gen welfare=0

qui forv k=1/500{

gen r = uniform() if price1!=.
sort r
    gen select =_n==1
	merge m:1 product using pe.dta, nogen  	
	
	gen concost_`k'=-(P1*sh_1+P2*sh_2+P3*sh_3+P4*sh_4+P5*sh_5+P6*sh_6)
	gen dz`k'=(P1*mp_1+P2*mp_2+P3*mp_3+P4*mp_4+P5*mp_5+P6*mp_6)
	
replace k=`k'
replace csum=csum+concost_`k'
replace cmean=csum/`k'

replace csqdev=csqdev+((cmean-concost_`k')^2)
replace cse=sqrt(csqdev/(`k'*(`k'-1)))

replace wsum=wsum+concost_`k'
replace wmean=wageeff_imperfect+csum/`k'

replace wsqdev=wsqdev+((cmean-concost_`k')^2) 
replace wse=sqrt(wsqdev/(`k'*(`k'-1)))

	replace zsum=zsum+dz`k'
	replace zmean=zsum/`k'
			sum zmean if mpoor==1 
			scalar line=pline*(1+r(mean))
	

		gen newpoor`k'=0
        replace newpoor`k'=1 if new_pce2<=line
	    gen pinc`k'=newpoor`k'-poorhh
		
		sum pinc`k' [fw=hhwt]
			gen np`k'=r(mean)
	    replace psum=psum+np`k'
        replace pmean=psum/`k'

		replace psqdev=psqdev+((pmean-np`k')^2)
        replace pse=sqrt(psqdev/(`k'*(`k'-1)))
		
drop concost_`k' dz`k' pinc`k' newpoor`k' np`k' 
}


		
	gen cmean100i=cmean*100
	gen wmean100i=wmean*100
    gen wageeff100i=wageeff_imperfect*100 if wmean!=.
	gen cse100i=cse*100
	gen ese100i=ese2*100
	gen wse100i=wse*100
	
	save hh66_urban_imperfect.dta,replace

		log on

		*Urban Imperfect (Table 10)
		mean *100 [fw = hhwt], over(q)
		*Urban Imperfect (Table 11)
		mean pmean pse [fw = hhwt]
	
		log off

		merge 1:1 id using hh66_urban_perfect.dta, keepusing(cmean100 cse100 wageeff100 ese100 wmean100 wse100)

	*Lpoly Graphs Data (Figures 5, 6 and 7):

lpoly cmean100i lmpce, bwidth(1) degree(1) noscatter generate(grid cons_ui) nograph se(secons)
lpoly wageeff100i lmpce, bwidth(1) degree(1) noscatter generate(grid2 wage_ui) nograph se(sewage)
lpoly wmean100i lmpce, bwidth(1) degree(1) noscatter generate(grid3 welf_ui) nograph se(sewelf)

		gen l_ci1_ui=cons_ui-1.96*secons
		gen u_ci1_ui=cons_ui+1.96*secons
		gen l_ci2_ui=wage_ui-1.96*sewage
		gen u_ci2_ui=wage_ui+1.96*sewage
		gen l_ci3_ui=welf_ui-1.96*sewelf
		gen u_ci3_ui=welf_ui+1.96*sewelf


save hh66_urban_imperfect.dta,replace

			keep cons wage_ui gridu welf_ui l_ci* u_ci*
			joinby gridu using lpolyresults.dta, unmatched(both) 
			save lpolyresults.dta, replace	

*** The Variation in Welfare Effects  (Table 12)

*Rural

use hh66_rural_perfect.dta, replace

		recode religion (1=1 "Hindu") (2/9=2 "Islam and Other"), gen(rel)
		gen skill=0 if headedu!=. 
		replace skill=1 if headedu>1
	 
log on

		ttest cmean100, by(landown)
		ttest wage100, by(landown)
		ttest wmean100, by(landown)

		ttest cmean100, by(skill)
		ttest wage100, by(skill)
		ttest wmean100, by(skill)

		ttest cmean100, by(headsex)
		ttest wage100, by(headsex)
		ttest wmean100, by(headsex)

		ttest cmean100, by(rel)
		ttest wage100, by(rel)
		ttest wmean100, by(rel)

log off

save hh66_rural_perfect.dta, replace


*Urban

use hh66_urban_perfect.dta, clear

recode religion (1=1 "Hindu") (2/9=2 "Islam and Other"), gen(rel)
gen skill=0 if headedu!=. 
replace skill=1 if headedu>1

log on
 
		ttest cmean100, by(landown)
		ttest wage100, by(landown)
		ttest wmean100, by(landown)

		ttest cmean100, by(skill)
		ttest wage100, by(skill)
		ttest wmean100, by(skill)

		ttest cmean100, by(headsex)
		ttest wage100, by(headsex)
		ttest wmean100, by(headsex)

		ttest cmean100, by(rel)
		ttest wage100, by(rel)
		ttest wmean100, by(rel)

log off

save hh66_urban_perfect.dta, replace

*** Graphs: 
*** ---------------

* Figure 5, 6 and 7:  

use lpolyresults.dta, clear

twoway (line  cons_rp  gridr, lcolor(ebblue) lwidth(thick) lpattern(solid)) ///
	   (line  cons_ri  gridr, lcolor(ebblue) lwidth(medthick) lpattern(longdash)) ///
	   (line  l_ci1_rp  gridr, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   (line  u_ci1_rp  gridr, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   (line  l_ci1_ri  gridr, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   (line  u_ci1_ri  gridr, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   (line  cons_up  gridu, lcolor(cranberry) lwidth(thick) lpattern(solid)) ///
	   (line  cons_ui  gridu, lcolor(cranberry) lwidth(medthick) lpattern(longdash)) ///
	   (line  l_ci1_up  gridu, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   (line  u_ci1_up  gridu, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   (line  l_ci1_ui  gridu, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   (line  u_ci1_ui  gridu, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   , ytitle(Consumption effect (%), size(medium)) ///
	   xtitle(Log per-capita expenditure, size(medium)) ///
	    scheme(s1color) graphregion(fcolor(none) ifcolor(none)) plotregion(fcolor(none) ifcolor(none)) ///
	   legend(on order(1 "Rural (perfect)" 2 "Rural (imperfect)" ///
	   7 "Urban (perfect)" 8 "Urban (imperfect)") size(medium)) ///
	   xlabel(, labsize(medium)) ylabel(, labsize(medium))  

	   
	 graph save cons_combined, replace
	 graph export cons_combined.pdf, as(pdf) replace 
   
	   
twoway (line  wage_rp  gridr, lcolor(ebblue) lwidth(thick) lpattern(solid)) ///
	   (line  wage_ri  gridr, lcolor(ebblue) lwidth(medthick) lpattern(longdash)) ///
	   (line  l_ci2_rp  gridr, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   (line  u_ci2_rp  gridr, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   (line  l_ci2_ri  gridr, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   (line  u_ci2_ri  gridr, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   (line  wage_up  gridu, lcolor(cranberry) lwidth(thick) lpattern(solid)) ///
	   (line  wage_ui  gridu, lcolor(cranberry) lwidth(medthick) lpattern(longdash)) ///
	   (line  l_ci2_up  gridu, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   (line  u_ci2_up  gridu, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   (line  l_ci2_ui  gridu, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   (line  u_ci2_ui  gridu, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   , ytitle(Wage effect (%), size(medium)) ///
	   xtitle(Log per-capita expenditure, size(medium)) ///
	    scheme(s1color) graphregion(fcolor(none) ifcolor(none)) plotregion(fcolor(none) ifcolor(none)) ///
	   legend(on order(1 "Rural (perfect)" 2 "Rural (imperfect)" ///
	   7 "Urban (perfect)" 8 "Urban (imperfect)") size(medium)) ///
	   xlabel(, labsize(medium)) ylabel(, labsize(medium))  
	   
	 graph save wage_combined, replace
	 graph export wage_combined.pdf, as(pdf) replace
	   
	   
twoway (line  welf_rp  gridr, lcolor(ebblue) lwidth(thick) lpattern(solid)) ///
	   (line  welf_ri  gridr, lcolor(ebblue) lwidth(medthick) lpattern(longdash)) ///
	   (line  l_ci3_rp  gridr, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   (line  u_ci3_rp  gridr, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   (line  l_ci3_ri  gridr, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   (line  u_ci3_ri  gridr, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   (line  welf_up  gridu, lcolor(cranberry) lwidth(thick) lpattern(solid)) ///
	   (line  welf_ui  gridu, lcolor(cranberry) lwidth(medthick) lpattern(longdash)) ///
	   (line  l_ci3_up  gridu, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   (line  u_ci3_up  gridu, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   (line  l_ci3_ui  gridu, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   (line  u_ci3_ui  gridu, lwidth(medium) lcolor(gs9) lpattern(shortdash)) ///
	   , ytitle(Net effect (%), size(medium)) ///
	   xtitle(Log per-capita expenditure, size(medium)) ///
	    scheme(s1color) graphregion(fcolor(none) ifcolor(none)) plotregion(fcolor(none) ifcolor(none)) ///
	   legend(on order(1 "Rural (perfect)" 2 "Rural (imperfect)" ///
	   7 "Urban (perfect)" 8 "Urban (imperfect)") size(medium)) ///
	   xlabel(, labsize(medium)) ylabel(, labsize(medium))  
	   
	 graph save welfare_combined, replace
	 graph export welfare_combined.pdf, as(pdf) replace
	   
save lpolyresults.dta, clear



* Monte Carlo results presentation (Figure 3) 

	use MCResults_Table4.dta, clear

	global vars Rice Wheat Corn Sugar Other Meat
	
foreach var in $vars {

			hist `var'_per if (z_`var'>-2 & z_`var'<2), normal normopts(lcolor(cranberry) lwidth(medthick)) ///
				fcolor(bluishgray) lcolor(ebbblue) ///
				graphregion(fcolor(white) lcolor(white) lpattern(blank) ifcolor(white) ///
				ilcolor(yellow) ilpattern(blank)) ///
				plotregion(fcolor(none) ifcolor(none)) ///
				ytitle(Density, size(medium)) ///
				xtitle(`var', size(medium))
				
			graph export `var'price.pdf, as(pdf) replace
}



** Kernel Density Graphs (Figure 8): 

use hh66_rural,clear
kdensity lmpce if z_lmpce>-4 & z_lmpce<4 [fweight = hhwt], bwidth(0.5) generate(gridr kernelr)
		keep gridr kernelr
		save kernelr.dta, replace

use hh66_urban,clear
kdensity lmpce if z_lmpce>-4 & z_lmpce<4 [fweight = hhwt], bwidth(0.5) generate(gridu kernelu)
keep gridu kernelu
		merge 1:1 _n using kernelr.dta
		save kernel.dta, replace

twoway (line kernelr gridr, lcolor(ebblue) lpattern(dash) lwidth(medthick)) (line kernelu gridu, lcolor(cranberry) lpattern(solid) lwidth(medthick)), ///
ytitle(Density) legend(order(1 "Rural" 2 "Urban")) ///
graphregion(fcolor(white) lcolor(white) lpattern(blank) ifcolor(white)) ///
xline(6.55, lstyle(foreground) lwidth(0.3)) ///
xlabel(, labsize(medium)) ylabel(, labsize(medium)) xtitle(Log per-capita expenditure, size(medium)) ytitle(, size(medium)) legend(size(medium))

graph export density.pdf, as(pdf) replace
	   

	   *** end ********
	   

