
*** This code replicates Price Pass-though results ***
*** Figure 4 and Table 7,8 based on pricedata.dta ***
*** ----------------------------------------------***

use price.dta, clear

** Table 7: 

foreach i in rice wheat sugar beef maize{ 

		scalar pch_`i'w=(`i'_w[137]-`i'_w[61])*100/`i'_w[61] 		
		scalar pch_`i'k=(`i'_d[137]-`i'_d[61])*100/`i'_d[61]
		
		display pch_`i'k
		display pch_`i'w
		display pch_`i'k / pch_`i'w
}


* Figure 4: 

twoway (line rice_w newt, sort lcolor(navy) lwidth(medthick) lpattern(dash)) ///
		(line rice_d newt, sort lcolor(maroon) lwidth(medthick) lpattern(solid)) ///
		if time>60, title(Rice) subtitle(Metric Ton (USD))
	save Graph_Rice.gph, replace

twoway (line sugar_w newt, sort lcolor(navy) lwidth(medthick) lpattern(dash)) ///
		(line sugar_d newt, sort lcolor(maroon) lwidth(medthick) lpattern(solid)) ///
		if time > 60, title(Sugar) subtitle(Metric Ton (USD))
	save Graph_Sugar.gph, replace

twoway (line wheat_w newt, sort lcolor(navy) lwidth(medthick) lpattern(dash)) ///
		(line wheat_d newt, sort lcolor(maroon) lwidth(medthick) lpattern(solid)) ///
		if time>60, title(Wheat) subtitle(Metric Ton (USD))
	save Graph_Wheat.gph, replace

twoway (line maize_w newt, sort lcolor(navy) lwidth(medthick) lpattern(dash)) ///
		(line maize_d newt, sort lcolor(maroon) lwidth(medthick) lpattern(solid)) ///
		if time>60, title(Maize) subtitle(Kg (USD))
	save Graph_Maize.gph, replace

twoway (line beef_w newt, sort lcolor(navy) lwidth(medthick) lpattern(dash)) ///
		(line beef_d newt, sort lcolor(maroon) lwidth(medthick) lpattern(solid)) ///
		if time>60, title(Meat) subtitle(Kg (USD))
	save Graph_Meat.gph, replace


* Table 8: 

foreach j in w k d {
	foreach i in rice_`j' sugar_`j' wheat_`j' maize_`j' beef_`j' {
	gen l`i'`j'=ln(`i'_`j')
	gen dl`i'`j'=l`i'`j'-L1.`i'_`j'
	}
}
	
*Rice
reg dlricek dlricew L3.dlricew L6.dlricew L9.dlricew L12.dlricew dlex dltrice, noconstant
display _b[dlricew] 
test dlricew=1
test dlricew=0
display _b[dlricew]+_b[L3.dlricew]+_b[L6.dlricew]+_b[L9.dlricew]+_b[L12.dlricew] 
test dlricew+L3.dlricew+L6.dlricew+L9.dlricew+L12.dlricew=1
test dlricew+L3.dlricew+L6.dlricew+L9.dlricew+L12.dlricew=0

*Wheat
reg dlwheatk dlwheatw L3.dlwheatw L6.dlwheatw L9.dlwheatw L12.dlwheatw dlex dltwheat, noconstant
display _b[dlwheatw] 
test dlwheatw=1
test dlwheatw=0
display _b[dlwheatw]+_b[L3.dlwheatw]+_b[L6.dlwheatw]+_b[L9.dlwheatw]+_b[L12.dlwheatw]
test dlwheatw+L3.dlwheatw+L6.dlwheatw+L9.dlwheatw+L12.dlwheatw=1
test dlwheatw+L3.dlwheatw+L6.dlwheatw+L9.dlwheatw+L12.dlwheatw=0

*Sugar
reg dlsugark dlsugarw L3.dlsugarw L6.dlsugarw L9.dlsugarw L12.dlsugarw dlex dltsugar, noconstant
display _b[dlsugarw] 
test dlsugarw=1
test dlsugarw=0
display _b[dlsugarw]+_b[L3.dlsugarw]+_b[L6.dlsugarw]+_b[L9.dlsugarw]+_b[L12.dlsugarw]
test dlsugarw+L3.dlsugarw+L6.dlsugarw+L9.dlsugarw+L12.dlsugarw=1
test dlsugarw+L3.dlsugarw+L6.dlsugarw+L9.dlsugarw+L12.dlsugarw=0

*Meat
reg dlbeefk dlbeefw L3.dlbeefw L6.dlbeefw L9.dlbeefw L12.dlbeefw dlex dltmeat, noconstant
display _b[dlbeefw]
test dlbeefw=1
test dlbeefw=0
display _b[dlbeefw]+_b[L3.dlbeefw]+_b[L6.dlbeefw]+_b[L9.dlbeefw]+_b[L12.dlbeefw]
test dlbeefw+L3.dlbeefw+L6.dlbeefw+L9.dlbeefw+L12.dlbeefw=1
test dlbeefw+L3.dlbeefw+L6.dlbeefw+L9.dlbeefw+L12.dlbeefw=0

*Corn
reg dlmaizek dlmaizew L3.dlmaizew L6.dlmaizew L9.dlmaizew L12.dlmaizew dlex dltmaize, noconstant
display _b[dlmaizew]
test dlmaizew=1
test dlmaizew=0
display _b[dlmaizew]+_b[L3.dlmaizew]+_b[L6.dlmaizew]+_b[L9.dlmaizew]+_b[L12.dlmaizew]
test dlmaizew+L3.dlmaizew+L6.dlmaizew+L9.dlmaizew+L12.dlmaizew=1
test dlmaizew+L3.dlmaizew+L6.dlmaizew+L9.dlmaizew+L12.dlmaizew=0 

*--- end ---*

