
*** This code replicates the results for distributional effects through wages  *** 
*** Tables 6 and 9 based on Schedule 10 of NSS 61 and NSS 66 data ***
***--------------------------------------------------------------------------------------------***


use emp66.dta, clear

merge m:1 nic using conc.dta, nogenerate 
replace product=0 if product==. & nic!=.    

 egen decile=xtile(lmpce), by(sector) nq(10)
 
*Table 6: Employment Shares:

forv i=1/10{
display `i'
tab product if sector==1 & q==`i'
}

forv i=1/10{
display `i'
tab product if sector==2 & q==`i'
}

forv i=1/5{
display `i'
tab product if sector==1 & q2==`i'
}

forv i=1/5{
display `i'
tab product if sector==2 & q2==`i'
}
	

use income.dta, clear 

gen count=1

** Price data:

** round 61:  
use c61.dta,clear

     recode item (129=1 grains) (269 =3 sugar) (181/186=4 meat) ///
	      (139 159 229 249 259 289=5 other) (else=0)  , gen(product)
	 drop if prod==0
			
			gen pr_=vl30/qn30			
	
	 collapse (mean) pr_ [fw=hhwt], by(sector stdistrict product)
	 
	 decode product, gen(product2)
     drop product
     reshape wide pr_, i(sector stdistrict) j(product2) string
 
     gen year=2005
	
	 save NSSprice.dta, replace
	 
	 
* round 66
use c66.dta,clear

recode item (129=1 grains) (179 =3 sugar) (201/206=4 meat) ///
	      (139 159=5 other) (249 269 279 289=57 other7) (else=0)  , gen(product)
	 drop if prod==0 	 
			 
			gen pr_=vl30/qn30
						
     collapse (mean) pr_ [fw = hhwt], by(sector stdistrict product)
	 			 
	 decode product, gen(product2)
     drop product
     reshape wide pr_, i(sector stdistrict) j(product2) string

	 gen year=2010

	  append using NSSprice.dta
	  by year, sort : sum pr_*
	  save NSSprice.dta" replace

** regression
use income.dta, clear 
merge m:1 stdistrict sector year using NSSprice.dta, nogen

drop if product==.
by year state district, sort : egen float emp_totdist = total(count==1)  
by year state, sort : egen float emp_totstate = total(count==1) 
  	forv i=1/5 {
	
		by year state district, sort : egen float emp_`i' = total(product==`i')  
		by year state, sort : egen float empstate_`i' = total(product==`i')  
		gen empex_`i'=empstate_`i'-emp_`i'
		gen empsh_`i'=emp_`i'/emp_totdist   
		gen empshex_`i'=empex_`i'/emp_totstate 			
 }	
 
	collapse (mean) empsh_* empshex_* if year==2005 , by(year stdistrict product)
	drop year
	save empshare_55.dta, replace

	use income.dta
	merge m:1 stdistrict product using empshare_55.dta, nogen


gen price=0
gen priceex=0

forv i=1/5 {

	replace price=price+ empsh`i'*pr`i'
	replace pricex=priceex+ empshex`i'*pr`i'

}
	
gen age2=age^2
gen skill=0 if edu!=.
replace skill=1 if edu>1
	tab skill year
	
	keep if age>=15 & age<=65
	keep if wage_tot!=0
	
gen learn=ln(wage_tot)
gen lnprice=ln(price)
gen lnpriceex=ln(priceex)


* Table 9: 

xi: reg learn lnprice age age2 male married i.edu i.state*i.year if sector==1 & skill==0, cluster(district)
xi: reg learn lnprice age age2 male married i.edu i.state*i.year if sector==1 & skill==1, cluster(district)
xi: reg learn lnprice age age2 male married i.edu i.state*i.year if sector==2 & skill==0, cluster(district)
xi: reg learn lnprice age age2 male married i.edu i.state*i.year if sector==2 & skill==1, cluster(district)
xi: ivreg2 learn (lnprice=lnpriceex) age age2 male married i.edu i.state*i.year if sector==1 & skill==0, cluster(district) first
	estat firststage
xi: ivreg2 learn (lnprice =lnpriceex) age age2 male married i.edu i.state*i.year if sector==1 & skill==1, cluster(district) first
	estat firststage
xi: ivreg2 learn (lnprice =lnpriceex) age age2 male married i.edu i.state*i.year if sector==2 & skill==0, cluster(district) first
	estat firststage
xi: ivreg2 learn (lnprice =lnpriceex) age age2 male married i.edu i.state*i.year if sector==2 & skill==1, cluster(district) first
	estat firststage
	


*** Iterations seperately for rural/urban ***

* perfect pass-through - rural: 	
	
	use emp66_rural.dta, clear
	
    gen k=0
	gen emean=0
	gen esum=0
	gen esqdev=0
	gen ese=0
	

qui forv k=1/500 {
use MCResults.dta, clear

gen r = uniform()
  sort r
gen select =_n==1
  keep if select==1
drop r        
  reshape long price, i(select) j(product)
  merge 1:m product using emp66_rural.dta, nogen  
     
       gen wageeff`k'=welas10*price if earn!=0 & earn!=. & skill==0
	   replace wageeff`k'=welas11*price if earn!=0 & earn!=. & skill==1
	 
	      replace k=`k'
		  replace esum=esum+wageeff`k'
		  replace emean=esum/`k'
		
	replace esqdev=esqdev+((emean-wageeff`k')^2)
    replace ese=sqrt(esqdev/(k*(k-1)))
drop wageeff`k'
save emp66_rural.dta, replace

}

replace emean=0 if emean==. 
gen wageeff=emean/hhexp
collapse (sum) wageeff emean earn (mean) ese hhexp hhsize hhwt mpce lmpce [fweight = hhwt], by(hhid)
mean emean ese [fw=hhwt]

save emp66_rural.dta, replace

* perfect pass-through - urban: 

use emp66_urban.dta, clear

	gen k=0
	gen emean=0
	gen esum=0
	gen esqdev=0
	gen ese=0
	
qui forv k=1/500 {
use MCResults.dta, clear

gen r = uniform()
  sort r
gen select =_n==1
  keep if select==1
drop r        
  reshape long price, i(select) j(product)
  merge 1:m product using emp66_urban.dta, nogen  
     
       gen wageeff`k'=welas20*price if earn!=0 & earn!=. & skill==0
	   replace wageeff`k'=welas21*price if earn!=0 & earn!=. & skill==1
	   
	      replace k=`k'
		  replace esum=esum+wageeff`k'
		  replace emean=esum/`k'
		
	replace esqdev=esqdev+((emean-wageeff`k')^2)
    replace ese=sqrt(esqdev/(k*(k-1)))
drop wageeff`k'
save emp66_urban.dta, replace

}

replace emean=0 if emean==. 
gen wageeff=emean/hhexp
collapse (sum) emean earn wageff (mean) ese hhexp hhsize hhwt mpce lmpce [fweight = hhwt], by(hhid)
mean emean ese [fw=hhwt]

save emp66_urban.dta, replace

** imperfect pass-through - rural

	use emp66_rural.dta, clear

 merge m:1 product using pe.dta, nogen  

    gen k=0
	gen emean2=0
	gen esum2=0
	gen esqdev2=0
	gen ese2=0
	gen pr2=0
	
qui forv k=1/500{
use MCResults.dta, clear

gen r = uniform()
  sort r
gen select =_n==1
  keep if select==1
drop r        
  reshape long price, i(select) j(product)
  merge 1:m product using pe.dta, nogen   
  merge 1:m product using emp66_rural.dta, nogen   
  replace pr2=price*pe
     
	   gen wageeff`k'=welas10*pr2 if earn!=0 & earn!=. & skill==0
	   replace wageeff`k'=welas11*pr2 if earn!=0 & earn!=. & skill==1
	   
          replace k=`k'
		  replace esum2=esum2+wageeff`k'
		  replace emean2=esum2/`k'
		
	replace esqdev2=esqdev2+((emean2-wageeff`k')^2)
    replace ese2=sqrt(esqdev2/(k*(k-1)))
drop wageeff`k'
save emp66_rural.dta, replace
}

replace emean2=0 if emean2==.

gen wageeff=emean2/hhexp
collapse (sum) emean2 earn wageff (mean) ese2 hhexp hhsize hhwt mpce lmpce [fweight = hhwt], by(hhid)
mean emean2 ese2 [fw=hhwt]

save emp66_rural_imp.dta, replace

** imperfect pass-through - urban

	use emp66_urban.dta, clear

merge m:1 product using pe.dta, nogen

    gen k=0
	gen emean2=0
	gen esum2=0
	gen esqdev2=0
	gen ese2=0
	gen pr2=0
	
qui forv k=1/500{
use MCResults.dta, clear

gen r = uniform()
  sort r
gen select =_n==1
  keep if select==1
drop r        
  reshape long price, i(select) j(product)
  merge 1:m product using pe.dta, nogen   
  merge 1:m product using emp66_urban.dta, nogen   
  replace pr2=price*pe
     
  	   gen wageeff`k'=welas20*pr2 if earn!=0 & earn!=. & skill==0
	   replace wageeff`k'=welas21*pr2 if earn!=0 & earn!=. & skill==1

	      replace k=`k'
		  replace esum2=esum2+wageeff`k'
		  replace emean2=esum2/`k'
		
	replace esqdev2=esqdev2+((emean2-wageeff`k')^2)
    replace ese2=sqrt(esqdev2/(k*(k-1)))
drop wageeff`k'
save emp66_urban.dta, replace
}


replace emean2=0 if emean2==.
gen wageeff=emean2/hhexp
collapse (sum) emean2 earn wageff (mean) ese2 hhexp hhsize hhwt mpce lmpce [fweight = hhwt], by(hhid)
mean emean2 ese2 [fw=hhwt]
save emp66_urban_imp.dta, replace

*****end************
